@@ -3,11 +3,12 @@
 
 int luaopen_nsock(lua_State *);
 int l_nsock_new(lua_State *);
-int l_nsock_loop(int tout);
 int l_nsock_sleep(lua_State *L);
 
 int l_dnet_new(lua_State *);
 int l_dnet_get_interface_link(lua_State *);
 
+#define NSE_NSOCK_LOOP "NSOCK_LOOP"
+
 #endif
 
