@@ -1,25 +1,90 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2005,2008 Insecure.Com LLC.
-#
-# Author: Adriano Monteiro Marques <py.adriano@gmail.com>
-#         Cleber Rodrigues <cleber.gnu@gmail.com>
-# Modified: Jurand Nogiec <jurand@jurand.net>, 2008
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# ***********************IMPORTANT NMAP LICENSE TERMS************************
+# *                                                                         *
+# * The Nmap Security Scanner is (C) 1996-2009 Insecure.Com LLC. Nmap is    *
+# * also a registered trademark of Insecure.Com LLC.  This program is free  *
+# * software; you may redistribute and/or modify it under the terms of the  *
+# * GNU General Public License as published by the Free Software            *
+# * Foundation; Version 2 with the clarifications and exceptions described  *
+# * below.  This guarantees your right to use, modify, and redistribute     *
+# * this software under certain conditions.  If you wish to embed Nmap      *
+# * technology into proprietary software, we sell alternative licenses      *
+# * (contact sales@insecure.com).  Dozens of software vendors already       *
+# * license Nmap technology such as host discovery, port scanning, OS       *
+# * detection, and version detection.                                       *
+# *                                                                         *
+# * Note that the GPL places important restrictions on "derived works", yet *
+# * it does not provide a detailed definition of that term.  To avoid       *
+# * misunderstandings, we consider an application to constitute a           *
+# * "derivative work" for the purpose of this license if it does any of the *
+# * following:                                                              *
+# * o Integrates source code from Nmap                                      *
+# * o Reads or includes Nmap copyrighted data files, such as                *
+# *   nmap-os-db or nmap-service-probes.                                    *
+# * o Executes Nmap and parses the results (as opposed to typical shell or  *
+# *   execution-menu apps, which simply display raw Nmap output and so are  *
+# *   not derivative works.)                                                * 
+# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
+# *   installer, such as those produced by InstallShield.                   *
+# * o Links to a library or executes a program that does any of the above   *
+# *                                                                         *
+# * The term "Nmap" should be taken to also include any portions or derived *
+# * works of Nmap.  This list is not exclusive, but is meant to clarify our *
+# * interpretation of derived works with some common examples.  Our         *
+# * interpretation applies only to Nmap--we don't speak for other people's  *
+# * GPL works.                                                              *
+# *                                                                         *
+# * If you have any questions about the GPL licensing restrictions on using *
+# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
+# * we also offer alternative license to integrate Nmap into proprietary    *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates as well as helping to     *
+# * fund the continued development of Nmap technology.  Please email        *
+# * sales@insecure.com for further information.                             *
+# *                                                                         *
+# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * permission to link the code of this program with any version of the     *
+# * OpenSSL library which is distributed under a license identical to that  *
+# * listed in the included COPYING.OpenSSL file, and distribute linked      *
+# * combinations including the two. You must obey the GNU GPL in all        *
+# * respects for all of the code used other than OpenSSL.  If you modify    *
+# * this file, you may extend this exception to your version of the file,   *
+# * but you are not obligated to do so.                                     *
+# *                                                                         *
+# * If you received these files with a written license agreement or         *
+# * contract stating terms other than the terms above, then that            *
+# * alternative license agreement takes precedence over these comments.     *
+# *                                                                         *
+# * Source is provided to this software because we believe users have a     *
+# * right to know exactly what a program is going to do before they run it. *
+# * This also allows you to audit the software for security holes (none     *
+# * have been found so far).                                                *
+# *                                                                         *
+# * Source code also allows you to port Nmap to new platforms, fix bugs,    *
+# * and add new features.  You are highly encouraged to send your changes   *
+# * to nmap-dev@insecure.org for possible incorporation into the main       *
+# * distribution.  By sending these changes to Fyodor or one of the         *
+# * Insecure.Org development mailing lists, it is assumed that you are      *
+# * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
+# * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
+# * will always be available Open Source, but this is important because the *
+# * inability to relicense code has caused devastating problems for other   *
+# * Free Software projects (such as KDE and NASM).  We also occasionally    *
+# * relicense the code to third parties as discussed above.  If you wish to *
+# * specify special license conditions of your contributions, just say so   *
+# * when you send them.                                                     *
+# *                                                                         *
+# * This program is distributed in the hope that it will be useful, but     *
+# * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+# * General Public License v2.0 for more details at                         *
+# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
+# * included with Nmap.                                                     *
+# *                                                                         *
+# ***************************************************************************/
 
 import gtk
 
@@ -34,10 +99,11 @@ from zenmapGUI.higwidgets.higwindows import HIGMainWindow
 from zenmapGUI.higwidgets.higdialogs import HIGDialog, HIGAlertDialog
 from zenmapGUI.higwidgets.higlabels import HIGEntryLabel
 from zenmapGUI.higwidgets.higboxes import HIGHBox, HIGVBox
+from zenmapGUI.higwidgets.higlabels import HIGSectionLabel
 
 import zenmapGUI.App
 from zenmapGUI.FileChoosers import *
-from zenmapGUI.ScanNotebook import ScanInterface
+from zenmapGUI.ScanInterface import ScanInterface
 from zenmapGUI.ProfileEditor import ProfileEditor
 from zenmapGUI.About import About
 from zenmapGUI.DiffCompare import DiffWindow
@@ -51,6 +117,7 @@ from zenmapCore.RecentScans import recent_scans
 from zenmapCore.UmitLogging import log
 import zenmapCore.I18N
 from zenmapCore.UmitConf import SearchConfig, is_maemo
+from zenmapCore.NetworkInventory import FilteredNetworkInventory
 
 UmitScanWindow = None
 hildon = None
@@ -79,6 +146,8 @@ class ScanWindow(UmitScanWindow):
         self.set_title(_(APP_DISPLAY_NAME))
         self.set_default_size(-1, 650)
 
+        self.scan_interface = ScanInterface()
+
         self.main_accel_group = gtk.AccelGroup()
         
         self.add_accel_group(self.main_accel_group)
@@ -191,6 +260,13 @@ class ScanWindow(UmitScanWindow):
                 '<Control>f',
                 _('Search for a scan result'),
                 self._search_scan_result),
+
+            ('Filter Hosts',
+                gtk.STOCK_FIND,
+                _('Filter Hosts'),
+                '<Control>l',
+                _('Search for host by criteria'),
+                self._filter_cb),
             
             ('Edit Profile',
                 gtk.STOCK_PROPERTIES,
@@ -264,6 +340,7 @@ class ScanWindow(UmitScanWindow):
         <menu action='Tools'>
             <menuitem action='Compare Results'/>
             <menuitem action='Search Scan'/>
+            <menuitem action='Filter Hosts'/>
          </menu>
         
         <menu action='Profile'>
@@ -301,6 +378,9 @@ class ScanWindow(UmitScanWindow):
         search_window = SearchWindow(self._load_search_result, self._append_search_result)
         search_window.show_all()
 
+    def _filter_cb(self, widget):
+        self.scan_interface.toggle_filter_bar()
+
     def _load_search_result(self, results):
         """This function is passed as an argument to the SearchWindow.__init__ method.
         When the user selects scans in the search window and clicks on \"Open\", this
@@ -320,7 +400,11 @@ class ScanWindow(UmitScanWindow):
         log.debug(">>> Saving result into database...")
         try:
             scan_interface.inventory.save_to_db()
-        except ImportError, e:
+        except Exception, e:
+            alert = HIGAlertDialog(message_format = _("Can't save to database"),
+                secondary_text = _("Can't store unsaved scans to the recent scans database:\n%s") % str(e))
+            alert.run()
+            alert.destroy()
             log.debug(">>> Can't save result to database: %s." % str(e))
 
     def get_recent_scans(self):
@@ -359,7 +443,6 @@ class ScanWindow(UmitScanWindow):
         self.menubar.show_all()
 
     def _create_scan_interface(self):
-        self.scan_interface = ScanInterface()
         self.scan_interface.scan_result.scan_result_notebook.scans_list.append_button.connect("clicked", self._append_scan_results_cb)
         self.scan_interface.show_all()
         self.vbox.pack_start(self.scan_interface, True, True, 0)
@@ -614,13 +697,6 @@ This scan has not been run yet. Start the scan with the "Scan" button first.'))
         pe.set_scan_interface(self.scan_interface)
         pe.show_all()
     
-    def _alert_with_action_name_cb(self, p):
-        d = HIGAlertDialog(parent=self,
-                           message_format=p.get_name(),
-                           secondary_text=_("The text above is this action's name"))
-        d.run()
-        d.destroy()
-
     def _help_cb(self, action):
         show_help()
 
